
import click
import requests
import os
import subprocess as sb
import time


def run(command):
    sb.run(command, shell=True)


apps = '''
anaconda ------------- Anaconda- Powerful Tool for DS, DL and ML learners
atom-editor ---------- Atom Code Editor 
audacious ------------ Audacious Music Player
audacity ------------- Professional Audio Edition Software
blender-3.0 -------------- Open Source 3D Creation Suite
brave ---------------- Brave Browser- Fast, Light and Secure
brave-beta ----------- Brave Browser BETA- Regular updates and Bug Fixes
brave-nightly -------- Brave Nightly- Nightly Updates and Bug Fixes
calibre -------------- Free E-Book Suite
cheese --------------- Camera App for Linux
chrome --------------- Google Chrome Browser, the No.1 Browser in market
chromium ------------- Chromium Browser- A Light Browser like Chrome by GOOGLE
clang90 -------------- CLang Compiler for C
codeblocks-svn ------- Code::Blocks editor- Fast and Powerful
crystal -------------- Crystal language support
desmume -------------- DesMume Emulator for NDS and GB Games
discord -------------- Discord Client in Linux
dosbox -------------- DOS-BOX Emulator
dropbox -------------- Cloud Storage Client
microsoft-edge-dev-bin - MS Edge for Linux- Regular Updates 
emacs ---------------- Featureful Text Editor
etcher --------------- Professional ISO Disk Image Writer
evolution ------------ A lightweight yet reliable Mail Client
firefox -------------- Firefox Web Browser- Security at top
fish ----------------- Fish Shell
drive ---------------- Google Drive Client for Linux
google-earth-pro ----- Google Earth Feature for Linux
g++ ------------------ G++ Compiler for C/CPP
gcc ------------------ GCC Compiler for C
geany ---------------- Lightweight Text Editor
gedit ---------------- Casual Text Editor
geogebra-5 ----------- Applications for dealing with mathematical operations and visualizations
gimp ----------------- Professional Photo Edition Software
go ------------------- Go Language for Linux
gparted -------------- Manage your disks and partitions with GParted
htop ----------------- Monitor your resources with htop
intellij-idea-ce ----- IntelliJ IDEA Community Edition
jdk ------------------ JDK 11 for Linux
jedit----------------- Casual Text Editor
kate ----------------- Casual Text Editor
kazam ---------------- Light Screen Recorder for Linux
kdenlive ------------- Casual Video Edition Software
krita ---------------- Bring your artistic skills to life with Krita
lazarus-svn ---------- Pascal IDE 
libreoffice-dev-bin -- Complete Office Suite
lutris --------------- Open Source Gaming Platform for Linux
miniconda3 ----------- Miniconda- Light and Powerful
mypaint -------------- Draw beautiful art with MyPaint
nim ------------------ Nim Language Support
nodejs --------------- NodeJS for Linux
obs-studio ----------- Professional Screen Recorder
pinta ---------------- Draw beautiful images with Pinta
plank ---------------- Plank Dock for Desktop Linux
pycharm-community-edition -- PyCharm Community Edition
r -------------------- R Language for linux
rstudio-desktop ------ Best IDE for R Programming
scribus -------------- Professional DTP Software
shotwell ------------- Shotwell light casual Image Editor
signal-desktop ------- Signal client for Linux
simplescreenrecorder - Professional Screen Recorder
spotify -------------- Spotify Client
spyder --------------- An IDE for Scientists
steam ---------------- Steam Proton Client for Linux
sublime-text-dev ----- Sublime Text- A powerful yet lightweight Editor
telegram-desktop ------------- Telegram Client for Linux
terminator ----------- Terminal Manager Terminator
thonny --------------- Thonny Python Beginner's IDE
thunderbird ---------- Thunderbird Mail Client from Moz://a
vim ------------------ Professional Terminal Text Editor
virtualbox ----------- Make and Manage Virtual Machines with Vbox
vlc ------------------ No. 1 Media Player
visual-studio-code-bin - Visual Studio Code Text Editor
zoom ----------------- Zoom Client for Conferences and Meetings
and many more...
'''


@click.group()
@click.version_option('0.1.3', prog_name='lola')
def main():
    '''I am Lola! Your assistant who can help you setup your Linux in an easy way! You can know more about me in https://github.com/arghyagod-coder/lolaaur.
I can help you install apps through terminal, and you need to know almost nothing about the terminal to do so! Just simple prompts will be enough'''
    pass


@main.command('list', help='Check the list of supported apps!')
def list():
    print(apps)


@main.command('install', help=('Install an app'))
@click.argument('files', nargs=-1)
def install(files):
    for file in files:
    
        os.chdir(os.path.join(os.path.expanduser("~"), "Downloads"))

        pos= {
            f'https://aur.archlinux.org/packages/{file}' : [f'https://aur.archlinux.org/{file}.git', f'{file}'],
            f'https://aur.archlinux.org/packages/{file}-bin' : [f'https://aur.archlinux.org/{file}-bin.git', f'{file}-bin'],
            f'https://aur.archlinux.org/packages/{file}-git' : [f'https://aur.archlinux.org/{file}-git.git', f'{file}-git'] 
        }
        home = (os.path.expanduser('~'))
        i=0
        for key, value in pos.items():
            res = requests.get(key)
            if res.status_code!=404:
                run(f"git clone {value[0]}; cd {home}/Downloads/{value[1]};makepkg -si;cd ..;")
                run(f'rm -rf {home}/Downloads/{file}')
                i+=1
                break

        if i==0:
            try:
                sb.check_output(f'yay -S {file} -y', shell=True)
                run(f'yay -S {file} -y')
            except sb.CalledProcessError:
                click.echo(f"\n\n  -->> {file} was not found.")
        
        
@main.command('info', help='Know lola well!')
def info():
    click.echo("""
db       .d88b.  db       .d8b.  
88      .8P  Y8. 88      d8' `8b 
88      88    88 88      88ooo88 
88      88    88 88      88~~~88 
88booo. `8b  d8' 88booo. 88   88 
Y88888P  `Y88P'  Y88888P YP   YP 
                                 
I am lola! I am here to help you install software in your system fast and easily! 

Why use lola when we have those software managers?

Well, lola is a Command Line Interface and is used inside the terminal. And as we know, terminal downloads are way more faster than the software managers. While many softwares can be downloaded with a single pacman -S, most common ones need some more commands.

So I am here to make your life way more easier while installing software! This project targets both advanced and beginner users, because who doesn't like speedy and quicky stuff?

""")

@main.command('hack', help="A fun option to fake-hack a pc by giving it's username")
@click.argument('pc', nargs=1)
def hack(pc):
    i=0
    with click.progressbar(range(0,50)) as bar:
        for user in bar:
            i+=1
            time.sleep(0.23)
            click.echo(click.style(i, bg='black', fg='green'))
    click.echo(click.style(f'Entering into {pc} system...', bg='black', fg='green'))
    time.sleep(2)
    click.echo(click.style(f'Obtaining IP Address...', bg='black', fg='green'))
    time.sleep(2)
    click.echo(click.style('Obtained Data Successfully! Selling them to dark web!', bg='black', fg='green'))
    time.sleep(4)
    os.system('clear')
    click.echo(click.style('--SOLD DATA--', bg='black', fg='green'))
    click.echo(click.style('PHASE 1 COMPLETED!', bg='black', fg='green'))
    time.sleep(4)
    os.system('clear')
    click.echo(click.style('Now infecting the target with Viruses', bg='black', fg='green'))
    click.echo(click.style('List of Viruses: \n\n memz\nwannacry\nbutterfly-ware\n', bg='black', fg='green'))
    time.sleep(3)
    with click.progressbar(range(0,50)) as bar:
        for user in bar:
            i+=1
            time.sleep(0.10)
            click.echo(click.style('Installing VIRUSES.... \n Running them', bg='black', fg='green'))
            click.echo(click.style(i, bg='black', fg='green'))
    time.sleep(2)
    click.echo(click.style('Computer Infected Successfully!', bg='black', fg='green'))
    time.sleep(2)
    click.echo(click.style('Processing Data', bg='black', fg='green'))
    time.sleep(1)
    run('clear')
    click.echo(click.style(f'{pc} was hacked successfully!', bg='black', fg='green'))

@main.command('update', help='Update lolacli to the latest version')
def update():
    os.system(f'pip3 install lolaaur -U')

@main.command('search', help='Check Availability of an app in lola')
@click.argument('app', nargs=1)
def search(app):
    pos= [
            f'https://aur.archlinux.org/packages/{app}',
            f'https://aur.archlinux.org/packages/{app}-bin',
            f'https://aur.archlinux.org/packages/{app}-git' 
        ]
    i=0
    for key in pos:
        res = requests.get(key)
        if res.status_code!=404:
            i+=1

    if i==0:
        print(f'No package named {app} found')
    else:
        print(f'{app} available')

if __name__ == "__main__":
    main()
    


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lolaaur']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.1,<9.0.0', 'requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['lola = lolaaur.lolacli:main']}

setup_kwargs = {
    'name': 'lolaaur',
    'version': '0.1.3',
    'description': 'An AUR connected package manager with wide variety of packages',
    'long_description': "# Lola\n### `lolaAUR` : A simple CLI package manager for Arch/Arch Based Linux \n\n[![Downloads](https://static.pepy.tech/personalized-badge/lolaaur?period=total&units=abbreviation&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/lolaaur)\n\n**lola is made for linux users who want to download software fast and easy!**\n\nNow many will ask, Why use lola when we have those software managers?\n\nWell, lola is a Command Line Interface and is used inside the terminal. And as we know, terminal downloads are way more faster than the software managers. While many softwares can be downloaded with a single `sudo apt install`, most common ones need some more commands.\n\nSo `lola` is here to make your life way more easier while installing software! This project targets both advanced and beginner users, because who doesn't like speedy and quicky stuff?\n\n#### Dependencies\n+ `click` \n\n### Built with\n+ `Python 3.8.5` \n\n![python](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/languages/python.svg)\n\n\n## Installation\n\n#### Method 1 (Recommended):\n\nIf you dont have python3 and pip installed on your system, or are not that much of PYTHON CODER, use this method\n\n- Install wget with `sudo pacman -S wget`\n\n- In your terminal-\n\n```bash\ncd ~/Downloads;wget https://raw.githubusercontent.com/arghyagod-coder/lola/master/lolacli/install.sh; sudo bash install.sh\n```\n\n- Now `lola` is ready to work!\n\n#### Method 2\n\nIf you have python and pip installed in your computer, execute the following\n\n```bash\npip3 install lolacli\n```\n\nBut, there are some dependencies that you will need if you go for method 2. They are the following:\n\n- git (`sudo pacman -S git`)\n- yay (`sudo pacman -S yay`)\n\n## Supported Platforms:\n\n+ Operating System = Linux64 \n\n![lin](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/tools/bash.svg)\n    \n  - Arch Linux and Derivatives like Manjaro, Garuda etc\n\n### Guide\n\n- The help command\n\n```bash\n>lola --help\n\n\n  I am Lola! Your assistant who can help you setup your Linux in an easy way!\n  You can know more about me in https://github.com/arghyagod-coder/lolaaur.\n\n  I can help you install apps through terminal, and you need to know almost\n  nothing about the terminal to do so! Just simple prompts will be enough\n\nOptions:\n  --version  Show the version and exit.\n  --help     Show this message and exit.\n\nCommands:\n  list        Check the list of supported apps!\n  install     Install an app\n\n```\n\n- Check some supported apps of AUR by using the `lola list` command. This list only gives names of a few packages, but every package in AUR repos can be installed via lolaAUR\n\n```bash\n> lola list\n\n\nanaconda ------------- Anaconda- Powerful Tool for DS, DL and ML learners\natom-editor ---------- Atom Code Editor \naudacious ------------ Audacious Music Player\naudacity ------------- Professional Audio Edition Software\nblender-3.0 -------------- Open Source 3D Creation Suite\nbrave ---------------- Brave Browser- Fast, Light and Secure\nbrave-beta ----------- Brave Browser BETA- Regular updates and Bug Fixes\nbrave-nightly -------- Brave Nightly- Nightly Updates and Bug Fixes\ncalibre -------------- Free E-Book Suite\ncheese --------------- Camera App for Linux\nchrome --------------- Google Chrome Browser, the No.1 Browser in market\nchromium ------------- Chromium Browser- A Light Browser like Chrome by GOOGLE\nclang90 -------------- CLang Compiler for C\ncodeblocks-svn ------- Code::Blocks editor- Fast and Powerful\ncrystal -------------- Crystal language support\ndesmume -------------- DesMume Emulator for NDS and GB Games\ndiscord -------------- Discord Client in Linux\ndosbox -------------- DOS-BOX Emulator\ndropbox -------------- Cloud Storage Client\nmicrosoft-edge-dev-bin - MS Edge for Linux- Regular Updates \nemacs ---------------- Featureful Text Editor\n...\n```\n\n- Install an app through lola with the `lola install <appname>` command\n\n```bash\n> lola install etcher\n \n[sudo] password for user: \nresolving dependencies...\nlooking for conflicting packages...\n\nPackages (1) etcher-1.5.120-1\n\nTotal Installed Size:  36.26 MiB\n\n:: Proceed with installation? [Y/n] y\n(1/1) checking keys in keyring                                                    [##############################################] 100%\n(1/1) checking package integrity                                                  [##############################################] 100%\n(1/1) loading package files                                                       [##############################################] 100%\n(1/1) checking for file conflicts                                                 [##############################################] 100%\n(1/1) checking available disk space                                               [##############################################] 100%\n:: Processing package changes...\n(1/1) installing etcher                                                           [##############################################] 100%\nOptional dependencies for etcher\n    libnotify: for notifications [installed]\n:: Running post-transaction hooks...\n(1/3) Arming ConditionNeedsUpdate...\n(2/3) Updating icon theme caches...\n(3/3) Updating the desktop file MIME type cache...\n```\n\n- Search Option\n  - `lola search <appname>` checks the availability of an app in lola.\n  \n```bash\n> lola search vlc\n\nvlc available!\n```\n\n- `lola update` updates lola to the latest version\n  \n- **Fun Feature-** Use `lola hack <computer_name>` to perform a fake hack on any target pc >_<\n\n- `lola info` gives you a brief description of Lola\n\n## Developer Tools\n\n- [Python 3.8.5](https://www.python.org/ftp/python/3.8.5/Python-3.8.5.tar.xz) \n\n![python](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/languages/python.svg)\n\n- [Sublime Text 3](https://www.sublimetext.com/3)\n\n- [Visual Studio Code](https://code.visualstudio.com) \n\n![vscode](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/tools/visualstudio_code.svg)\n\n- [Git](https://git-scm.com/) \n\n![git](https://raw.githubusercontent.com/klaasnicolaas/ColoredBadges/new-badges/svg/dev/tools/git.svg)\n\n- [Python Poetry](https://python-poetry.org/) for package management and publishing\n\n## Release Notes\n\n- **Current Release- 0.1.2 (Initial Release)**\n\n### What's new?\n\n- Connections to AUR repository make lola very powerful\n- By chance, if there's no such repository in AUR, lola attempts to resolve the packages with other managers\n- Better Exception Handling\n- Added few fun features to enhance user experience\n\n#### Developers\n- [Arghya Sarkar](https://github.com/arghyagod-coder)\n\n## License\n\nLicense © 2021-Present Arghya Sarkar\n\nThis repository is licensed under the MIT license. See [LICENSE](https://github.com/arghyagod-coder/lolaaur/master/LICENSE) for details.\n\n## Special Notes\n\n- Contribution is appreciated! Visit the contribution guide in [Contribution Guide](CONTRIBUTING.md)\n- If you don't find an app in the supported app list, file an issue in [the issue page](https://github.com/arghyagod-coder/lolaaur/issues). Issues aren't ignored by the developers\n- Thanks for seeing my project!",
    'author': 'Arghya Sarkar',
    'author_email': 'arghyasarkar.joker@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/arghyagod-coder/lolaaur',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
